
Pet Store
=========

Version :openapi:version:`../OpenAPI-Specification/examples/v3.0/petstore.yaml`

.. sidebar:: Services

    .. openapi:toc:: ../OpenAPI-Specification/examples/v3.0/petstore.yaml

Services
""""""""
.. openapi:: ../OpenAPI-Specification/examples/v3.0/petstore.yaml
    :examples:
    :group:
    :group_examples:
    :entities:

Data Model
""""""""""

.. openapi:model:: ../OpenAPI-Specification/examples/v3.0/petstore.yaml
